
Paste this into Arduino IDE and upload to your ESP8266:
👉 (I'll give you the final combined code in the next message!)

#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BMP085.h>
#include <Adafruit_GFX.h>
#include <Adafruit_ST7735.h>
#include <SPI.h>
#include <DHT.h>

// BMP180 I2C pins
#define SDA_PIN D2
#define SCL_PIN D1

// TFT LCD pins
#define TFT_CS D8
#define TFT_RST D4
#define TFT_DC D3

// DHT11 setup
#define DHTPIN D6
#define DHTTYPE DHT11
DHT dht(DHTPIN, DHTTYPE);

// Sensor & Display objects
Adafruit_BMP085 bmp;
Adafruit_ST7735 tft = Adafruit_ST7735(TFT_CS, TFT_DC, TFT_RST);

void showWelcome() {
 tft.fillScreen(ST77XX_BLACK);
 tft.setTextColor(ST77XX_CYAN);
 tft.setTextSize(1);
 tft.setCursor(10, 30);
 tft.println("Welcome to");

 tft.setTextColor(ST77XX_YELLOW);
 tft.setCursor(10, 50);
 tft.println("Zorro's Hiking");

 tft.setCursor(10, 65);
 tft.println("Trail Tracker!");

 delay(3000);
 tft.fillScreen(ST77XX_BLACK);
}

void setup() {
 Wire.begin(SDA_PIN, SCL_PIN);
 Serial.begin(115200);

 tft.initR(INITR_BLACKTAB);
 tft.setRotation(1);
 tft.fillScreen(ST77XX_BLACK);

 dht.begin();
 showWelcome();

 if (!bmp.begin(0x77)) {
 Serial.println("BMP180 not found!");
 tft.setTextColor(ST77XX_RED);
 tft.setCursor(10, 30);
 tft.println("Sensor Error!");
 while (1);
 }
}

void loop() {
 float temp = bmp.readTemperature();
 float pressure = bmp.readPressure() / 100.0;
 float humidity = dht.readHumidity();

 // Clear screen
 tft.fillScreen(ST77XX_BLACK);

 // Header
 tft.setCursor(5, 5);
 tft.setTextColor(ST77XX_GREEN);
 tft.setTextSize(1);
 tft.println("Zorro Weather Node");

 // Temperature
 tft.setCursor(10, 25);
 tft.setTextColor(ST77XX_CYAN);
 tft.print("T");
 tft.print((char)247); // Degree symbol
 tft.print(": ");
 tft.setTextColor(ST77XX_WHITE);
 tft.print(temp, 1);
 tft.println(" C");

 // Pressure
 tft.setCursor(10, 40);
 tft.setTextColor(ST77XX_YELLOW);
 tft.print("P: ");
 tft.setTextColor(ST77XX_WHITE);
 tft.print(pressure, 1);
 tft.println(" hPa");

 // Humidity
 tft.setCursor(10, 55);
 tft.setTextColor(ST77XX_MAGENTA);
 tft.print("H: ");
 tft.setTextColor(ST77XX_WHITE);
 if (!isnan(humidity)) {
 tft.print(humidity, 1);
 tft.println(" %");
 } else {
 tft.println("N/A");
 }

 tft.setCursor(5, 70);
 tft.setTextColor(ST77XX_GREEN);
 tft.println("-------------------------");

 // Countdown from 25 → 1
 for (int i = 25; i >= 1; i--) {
 tft.fillRect(0, 85, 160, 40, ST77XX_BLACK);
 tft.setCursor(10, 95);
 tft.setTextColor(ST77XX_WHITE);
 tft.print("Update in: ");
 tft.print(i);
 tft.println(" sec");
 delay(1000);
 }

 // Final message for 20 sec
 tft.fillRect(0, 85, 160, 40, ST77XX_BLACK);
 tft.setTextColor(ST77XX_WHITE);
 tft.setCursor(10, 95);
 tft.println("Move to new");
 tft.setCursor(10, 110);
 tft.println("location & collect");
 tft.setCursor(10, 125);
 tft.println("data");

 delay(20000);
}